Struct Print
pub struct Print<T>(pub T)
where
T: Display;Available on crate feature
term only.Expand description
A command that prints the given displayable type.
Commands must be executed/queued for execution otherwise they do nothing.
Tuple Fields
0: TTrait Implementations
impl<T> Command for Print<T>where
T: Display,
impl<T> Command for Print<T>where
T: Display,
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
Write an ANSI representation of this command to the given writer.
An ANSI code can manipulate the terminal by writing it to the terminal buffer.
However, only Windows 10 and UNIX systems support this. Read more
fn execute_winapi(&self) -> Result<(), Error>
fn execute_winapi(&self) -> Result<(), Error>
Available on Windows only.
Execute this command. Read more
fn is_ansi_code_supported(&self) -> bool
fn is_ansi_code_supported(&self) -> bool
Available on Windows only.
Returns whether the ANSI code representation of this command is supported by windows. Read more
impl<T> Copy for Print<T>
impl<T> Eq for Print<T>
impl<T> StructuralPartialEq for Print<T>