Struct PrintStyledContent
pub struct PrintStyledContent<D>(pub StyledContent<D>)
where
D: Display;Available on crate feature
term only.Expand description
A command that prints styled content.
See StyledContent for more info.
Notes
Commands must be executed/queued for execution otherwise they do nothing.
Tuple Fields
0: StyledContent<D>Trait Implementations
impl<D> Clone for PrintStyledContent<D>
impl<D> Clone for PrintStyledContent<D>
fn clone(&self) -> PrintStyledContent<D>
fn clone(&self) -> PrintStyledContent<D>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<D> Command for PrintStyledContent<D>where
D: Display,
impl<D> Command for PrintStyledContent<D>where
D: Display,
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
Write an ANSI representation of this command to the given writer.
An ANSI code can manipulate the terminal by writing it to the terminal buffer.
However, only Windows 10 and UNIX systems support this. Read more
fn execute_winapi(&self) -> Result<(), Error>
fn execute_winapi(&self) -> Result<(), Error>
Available on Windows only.
Execute this command. Read more
fn is_ansi_code_supported(&self) -> bool
fn is_ansi_code_supported(&self) -> bool
Available on Windows only.
Returns whether the ANSI code representation of this command is supported by windows. Read more
impl<D> Copy for PrintStyledContent<D>
impl<D> Debug for PrintStyledContent<D>
impl<D> Debug for PrintStyledContent<D>
impl Display for PrintStyledContent<String>
impl Display for PrintStyledContent<String>