Struct SetAttribute
pub struct SetAttribute(pub Attribute);Available on crate feature
term only.Expand description
Tuple Fields
0: AttributeTrait Implementations
impl Clone for SetAttribute
impl Clone for SetAttribute
fn clone(&self) -> SetAttribute
fn clone(&self) -> SetAttribute
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Command for SetAttribute
impl Command for SetAttribute
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
Write an ANSI representation of this command to the given writer.
An ANSI code can manipulate the terminal by writing it to the terminal buffer.
However, only Windows 10 and UNIX systems support this. Read more
fn execute_winapi(&self) -> Result<(), Error>
fn execute_winapi(&self) -> Result<(), Error>
Available on Windows only.
Execute this command. Read more
fn is_ansi_code_supported(&self) -> bool
fn is_ansi_code_supported(&self) -> bool
Available on Windows only.
Returns whether the ANSI code representation of this command is supported by windows. Read more
impl Copy for SetAttribute
impl Debug for SetAttribute
impl Debug for SetAttribute
impl Display for SetAttribute
impl Display for SetAttribute
impl Eq for SetAttribute
impl PartialEq for SetAttribute
impl PartialEq for SetAttribute
impl StructuralPartialEq for SetAttribute