Struct SetAttributes
pub struct SetAttributes(pub Attributes);Available on crate feature
term only.Expand description
A command that sets several attributes.
See Attributes for more info.
Notes
Commands must be executed/queued for execution otherwise they do nothing.
Tuple Fields
0: AttributesTrait Implementations
impl Clone for SetAttributes
impl Clone for SetAttributes
fn clone(&self) -> SetAttributes
fn clone(&self) -> SetAttributes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Command for SetAttributes
impl Command for SetAttributes
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
Write an ANSI representation of this command to the given writer.
An ANSI code can manipulate the terminal by writing it to the terminal buffer.
However, only Windows 10 and UNIX systems support this. Read more
fn execute_winapi(&self) -> Result<(), Error>
fn execute_winapi(&self) -> Result<(), Error>
Available on Windows only.
Execute this command. Read more
fn is_ansi_code_supported(&self) -> bool
fn is_ansi_code_supported(&self) -> bool
Available on Windows only.
Returns whether the ANSI code representation of this command is supported by windows. Read more
impl Copy for SetAttributes
impl Debug for SetAttributes
impl Debug for SetAttributes
impl Eq for SetAttributes
impl PartialEq for SetAttributes
impl PartialEq for SetAttributes
impl StructuralPartialEq for SetAttributes